utils::globalVariables(c(
  "crudes","Contract","Settlement",
  "dflong", "dfwide", "expiry_table", "holidaysOil", "EIAkey",
  "a", "x", "df", "value", "series", "symbol", ".", "price",
  "cmdty", "Date", "expiry", "V1", "yield", "maturity", "contract", "us.df", "cf",
  "DoW", "Last.Trade", "Year", "key", "swap", "tick.prefix", "Month.Letter",
  "t.years", "t.periods", "disc.factor", "pv",
  "par", "usSwapCurves", "times", "day2next", "disc", "disc.float", "fixed", "floating", "net",
  "freq", "remainder", "week", "u", "sigma", "res", "s", "e",
  "calDays", "hol", "bizDays", "futs", "type", "expirationDate",
  "ticker", "name", "SupplyNOPEC", "SupplyOPEC", "Demand", "Inv_Change",
  "tickers_eia", "sd_category", "tick.r", "imports", "exports", "demand", "supply",
  "ref.opt.inputs", "ref.opt.outputs", "prices", "LightSweet.yield", "LightSweet",
  "HeavySour", "HeavySour.yield", "Element", "product", "max.prod", "info", "code",
  "Close", "fut.contract", "DaysFromExp", "reportDate", "opt", "adjusted", "ret",
  "table.AnnualizedReturns", "table.DownsideRiskRatio", "deliveryStartDate", "tradeCycle", "market", "trade.cycle.end"
))
